import { Gindex, GindexBitstring } from "./gindex";
import { Node } from "./node";
import { Proof, ProofInput } from "./proof";
export declare type Hook = (v: Tree) => void;
export declare class Tree {
    private _node;
    private hook?;
    constructor(node: Node, hook?: Hook);
    static createFromProof(proof: Proof): Tree;
    get rootNode(): Node;
    set rootNode(n: Node);
    get root(): Uint8Array;
    getNode(index: Gindex | GindexBitstring): Node;
    setNode(gindex: Gindex | GindexBitstring, n: Node, expand?: boolean): void;
    getRoot(index: Gindex | GindexBitstring): Uint8Array;
    setRoot(index: Gindex | GindexBitstring, root: Uint8Array, expand?: boolean): void;
    getSubtree(index: Gindex | GindexBitstring): Tree;
    setSubtree(index: Gindex | GindexBitstring, v: Tree, expand?: boolean): void;
    clone(): Tree;
    getSingleProof(index: Gindex): Uint8Array[];
    /**
     * Fast read-only iteration
     * In-order traversal of nodes at `depth`
     * starting from the `startIndex`-indexed node
     * iterating through `count` nodes
     */
    iterateNodesAtDepth(depth: number, startIndex: number, count: number): IterableIterator<Node>;
    /**
     * Fast read-only iteration
     * In-order traversal of nodes at `depth`
     * starting from the `startIndex`-indexed node
     * iterating through `count` nodes
     */
    getNodesAtDepth(depth: number, startIndex: number, count: number): Node[];
    getProof(input: ProofInput): Proof;
}
